@@ -19,7 +19,6 @@ from wikibaseintegrator.models import Claim, Reference, Snak
 from wikibaseintegrator.wbi_config import config as wbi_config
 from wikibaseintegrator import wbi_login, WikibaseIntegrator
 from lodstorage.sparql import SPARQL
-import pprint
 import dateutil.parser
 from wikibaseintegrator.wbi_enums import WikibaseDatePrecision
 
@@ -144,12 +143,13 @@ class Wikidata:
                 ?item wdt:P31 wd:%s.
                 ?item rdfs:label ?itemLabel.
                 # short name
-                ?item wdt:P1813 %s
+                BIND(%s as ?shortNameLabel )
+                ?item wdt:P1813 ?shortNameLabel
                 FILTER(LANG(?itemLabel)= "%s" )
               } UNION {
                 ?item wdt:P31 wd:%s.
+                BIND(%s as ?itemLabel )
                 ?item rdfs:label ?itemLabel.
-                FILTER(?itemLabel= %s )
               }
             }""" % (itemType,itemLabel,lang,itemType,itemLabel)
         endpointUrl="https://query.wikidata.org/sparql"
@@ -310,18 +310,22 @@ class Wikidata:
         claims = []
         errors = dict()
         qualifier_lookup = PropertyMapping.get_qualifier_lookup(property_mappings)
+        # check if there is a existing Q-Item identifier in the record
         item_mapping = PropertyMapping.get_item_mapping(property_mappings)
         if item_mapping is not None:
             if item_id is None:
                 item_id = record.get(item_mapping.column, None)
+        # get the properties excluding the item column
         properties = [pm for pm in property_mappings if not pm.is_qualifier() and not pm.is_item_itself()]
         for prop in properties:
             qualifier_mappings = qualifier_lookup.get(prop.column, None)
             prop_claims, claim_errors = self._get_statement_for_property(record, prop, qualifier_mappings, reference, lang)
+            # merge error dicts to one dict
             errors = {**errors, **claim_errors}
             claims.extend(prop_claims)
         label = self.sanitize_label(record.get("label", None))
         description = record.get("description", None)
+        # handle get or create case
         item = self.get_or_create_item(item_id)
         item.add_claims(claims)
         if label:
@@ -375,6 +379,7 @@ class Wikidata:
                 # add qualifier
                 if qualifier_mappings is not None:
                     qualifier_errors = self._add_qualifier_to_statement(record, statement, qualifier_mappings, lang)
+                    # merge error dicts to one dict
                     errors = {**errors, **qualifier_errors}
             if statement is not None:
                 claims.append(statement)
@@ -418,7 +423,7 @@ class Wikidata:
         Args:
             item_id: item to retrieve if None create a new item
         """
-        if item_id is None:
+        if item_id is None or isinstance(item_id,str) and item_id.strip()=="":
             item = self.wbi.item.new()
         else:
             item = self.wbi.item.get(item_id)
@@ -696,6 +701,19 @@ class PropertyMapping:
         """
         is_qualifier = not (self.qualifierOf is None or self.qualifierOf == "")
         return is_qualifier
+    
+    @classmethod
+    def getDefaultItemPropertyMapping(cls)->"PropertyMapping":
+        """
+        get the defaultItemPropertyMapping
+        """
+        if not hasattr(cls,"defaultItemPropertyMapping"):
+            cls.defaultItemPropertyMapping=PropertyMapping(
+                column="item",
+                propertyName="item",
+                propertyId=None,
+                propertyType=WdDatatype.item)
+        return cls.defaultItemPropertyMapping
 
     def is_item_itself(self) -> bool:
         """
@@ -728,12 +746,14 @@ class PropertyMapping:
     @classmethod
     def get_item_mapping(cls, property_mappings: List['PropertyMapping']) -> 'PropertyMapping':
         """
-        get the property mapping that is
+        get the property mapping that is used for the default "item" primary key
+        if no property is defined use the default "item" mapping 
         """
         for pm in property_mappings:
             if pm.is_item_itself():
                 return pm
-
+        pm=cls.getDefaultItemPropertyMapping()
+        return pm
 
 class UrlReference(Reference):
     """
